%define pypi_name Django
%define pkg_name django

Name:		python-%{pkg_name}
Version:	5.0.8
Release:	%mkrel 1
Summary:	A high-level Python Web framework
License:	BSD
Group:		Development/Python
Url:		https://pypi.org/project/Django
Source0:	%{pypi_source}
BuildArch:	noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:	pkgconfig(python3)

# for docs
BuildRequires:	python3dist(sphinx) >= 4.5.0
BuildRequires:	python3dist(sphinx-rtd-theme)

%description
Django is a high-level Python Web framework that encourages rapid development
and clean, pragmatic design.

Developed and used over the past two years by a fast-moving online-news
operation, Django was designed from scratch to handle two challenges: the
intensive deadlines of a newsroom and the stringent requirements of experienced
Web developers. It has convenient niceties for developing content-management
systems, but it's an excellent tool for building any Web site.

Django focuses on automating as much as possible and adhering to the
DRY principle.

%package -n python3-%{pkg_name}
Summary:	%{summary}
Group:		Development/Python
%{?python_provide:%python_provide python3-%{pkg_name}}

%description -n python3-%{pkg_name}
Django is a high-level Python Web framework that encourages rapid development
and clean, pragmatic design.

Developed and used over the past two years by a fast-moving online-news
operation, Django was designed from scratch to handle two challenges: the
intensive deadlines of a newsroom and the stringent requirements of experienced
Web developers. It has convenient niceties for developing content-management
systems, but it's an excellent tool for building any Web site.

Django focuses on automating as much as possible and adhering to the
DRY principle.

%prep
%setup -q -n %{pypi_name}-%{version}

# fix shebangs
find . \( -name "*.py" -o -name "*.py-tpl" \) -exec sed -i -e '1s|#!.*python[2,3]\?|#!%{__python3}|' {} \;

# empty files
for f in \
    django/contrib/staticfiles/models.py \
    django/contrib/humanize/models.py \
; do
  echo "# just a comment" > $f
done

# Fix Sphinx Build
sed -i 's|sphinx-build|sphinx-build-3|' docs/Makefile

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files django

# build documentation
rm -rf docs/{html,man}/*
make -C docs man
make -C docs html
rm -rf docs/_build/html/.{buildinfo,doctrees}

# install man pages
mkdir -p %{buildroot}%{_mandir}/man1/
cp -a docs/_build/man/* %{buildroot}%{_mandir}/man1/

# install bash completion script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -m 0644 -p extras/django_bash_completion \
   %{buildroot}%{_sysconfdir}/bash_completion.d/

%files -n python3-%{pkg_name} -f %{pyproject_files}
%doc AUTHORS LICENSE README.rst
%doc docs/_build/html
%{_mandir}/man1/*
%{_bindir}/django-admin
%{_sysconfdir}/bash_completion.d/django_bash_completion


%changelog
* Tue Aug 06 2024 kekepower <kekepower> 5.0.8-1.mga10
+ Revision: 2083876
- Update to version 5.0.8
 o https://www.djangoproject.com/weblog/2024/aug/06/security-releases/

* Fri May 10 2024 kekepower <kekepower> 5.0.6-1.mga10
+ Revision: 2063287
- Update to version 5.0.6

* Sun Apr 07 2024 kekepower <kekepower> 5.0.4-1.mga10
+ Revision: 2055316
- Update to version 5.0.4

* Thu Mar 07 2024 kekepower <kekepower> 5.0.3-1.mga10
+ Revision: 2048331
- Update to version 5.0.3

* Wed Mar 06 2024 kekepower <kekepower> 4.2.11-1.mga10
+ Revision: 2047842
- Update to version 4.2.11
+ wally <wally>
- use %%pyproject_buildrequires

* Tue Dec 19 2023 daviddavid <daviddavid> 4.2.7-2.mga10
+ Revision: 2019240
- rebuild for py3.12

* Wed Nov 15 2023 kekepower <kekepower> 4.2.7-1.mga10
+ Revision: 2006835
- Update to version 4.2.7

* Sun Oct 22 2023 papoteur <papoteur> 4.2.6-1.mga10
+ Revision: 2000159
- new 4.2.6

* Fri May 05 2023 papoteur <papoteur> 4.1.9-1.mga9
+ Revision: 1955912
- new 4.1.9

* Sun Apr 16 2023 kekepower <kekepower> 4.1.8-1.mga9
+ Revision: 1953106
- Update to version 4.1.8

* Mon Feb 20 2023 kekepower <kekepower> 4.1.7-1.mga9
+ Revision: 1944370
- Update to version 4.1.7

* Wed Feb 01 2023 papoteur <papoteur> 4.1.6-1.mga9
+ Revision: 1937384
- new 4.1.6

* Tue Jan 03 2023 kekepower <kekepower> 4.1.5-1.mga9
+ Revision: 1929548
- Update to version 4.1.5

* Wed Dec 07 2022 kekepower <kekepower> 4.1.4-1.mga9
+ Revision: 1918912
- Update to version 4.1.4

* Fri Nov 04 2022 kekepower <kekepower> 4.1.3-1.mga9
+ Revision: 1903279
- Update to version 4.1.3

* Sat Oct 22 2022 ghibo <ghibo> 4.1.2-1.mga9
+ Revision: 1898347
- Update to release 4.1.2

* Thu Sep 08 2022 neoclust <neoclust> 4.1.1-1.mga9
+ Revision: 1885985
- New version 4.1.1

* Tue Sep 06 2022 neoclust <neoclust> 4.1-1.mga9
+ Revision: 1884541
- New version

* Wed Aug 03 2022 kekepower <kekepower> 3.2.15-1.mga9
+ Revision: 1875009
- Update to version 3.2.15

* Tue Jul 05 2022 kekepower <kekepower> 3.2.14-1.mga9
+ Revision: 1867719
- Update to version 3.2.14

* Sun May 15 2022 papoteur <papoteur> 3.2.13-1.mga9
+ Revision: 1858198
- new 3.2.13 (mga#30273 and CVE-2022-28346)

* Tue Mar 29 2022 umeabot <umeabot> 3.2.12-2.mga9
+ Revision: 1832592
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 3.2.12-1.mga9
+ Revision: 1772418
- new version 3.2.12
- rebuild for python3.10

* Tue Jan 04 2022 neoclust <neoclust> 3.2.11-1.mga9
+ Revision: 1766874
- New version 3.2.11: Fixes CVE-2021-4511[56] and CVE-2021-45452 (mga#29843)

* Wed Dec 08 2021 neoclust <neoclust> 3.2.10-1.mga9
+ Revision: 1761058
- New version 3.2.10: Fixes CVE-2021-44420 (mga#29737)

* Thu Nov 04 2021 kekepower <kekepower> 3.2.9-1.mga9
+ Revision: 1753919
- Update to version 3.2.9

* Tue Oct 05 2021 kekepower <kekepower> 3.2.8-1.mga9
+ Revision: 1749561
- Update to version 3.2.8

* Thu Sep 02 2021 kekepower <kekepower> 3.2.7-1.mga9
+ Revision: 1744039
- Update to version 3.2.7

* Sun Jul 04 2021 kekepower <kekepower> 3.2.5-1.mga9
+ Revision: 1734630
- Update to version 3.2.5

* Sun Jun 06 2021 kekepower <kekepower> 3.2.4-1.mga9
+ Revision: 1729917
- Update to version 3.2.4

* Tue May 04 2021 kekepower <kekepower> 3.2.1-1.mga9
+ Revision: 1721332
- Update to version 3.2.1

* Thu Mar 18 2021 neoclust <neoclust> 3.1.7-2.mga9
+ Revision: 1704495
- Rebuild against python 3.9

* Sat Feb 27 2021 neoclust <neoclust> 3.1.7-1.mga9
+ Revision: 1693153
- New version 3.1.7: Fixes CVE-2021-23336 (mga#28395)

* Tue Feb 02 2021 neoclust <neoclust> 3.1.6-1.mga8
+ Revision: 1674576
- New version 3.1.6 (mga#24899)
+ guillomovitch <guillomovitch>
- new version 3.1.4

* Mon Nov 23 2020 guillomovitch <guillomovitch> 3.1.3-1.mga8
+ Revision: 1648649
- new version 3.1.3

* Sat Sep 05 2020 guillomovitch <guillomovitch> 3.1.1-1.mga8
+ Revision: 1622494
- new version 3.1.1

* Wed Jun 03 2020 neoclust <neoclust> 2.2.13-1.mga8
+ Revision: 1590184
- New version 2.2.13 (mga#24899)

* Wed Mar 04 2020 shlomif <shlomif> 2.2.11-1.mga8
+ Revision: 1553628
- New version 2.2.11

* Sun Feb 16 2020 umeabot <umeabot> 2.2.4-4.mga8
+ Revision: 1531929
- Mageia 8 Mass Rebuild

* Sun Sep 15 2019 daviddavid <daviddavid> 2.2.4-3.mga8
+ Revision: 1441374
- rebuild for python3.8

* Wed Aug 21 2019 wally <wally> 2.2.4-2.mga8
+ Revision: 1430723
- new version 2.2.4
- drop python2 support

* Wed Jul 10 2019 kekepower <kekepower> 1.11.22-1.mga8
+ Revision: 1419833
- Update to version 1.11.22

* Mon Feb 11 2019 kekepower <kekepower> 1.11.20-1.mga7
+ Revision: 1365325
- Update to version 1.11.20

* Tue Jan 15 2019 luigiwalser <luigiwalser> 1.11.18-5.mga7
+ Revision: 1357028
- obsolete one more python-django16 package

* Tue Jan 15 2019 luigiwalser <luigiwalser> 1.11.18-4.mga7
+ Revision: 1357008
- obsolete more ancient django stuff

* Mon Jan 14 2019 luigiwalser <luigiwalser> 1.11.18-3.mga7
+ Revision: 1356729
- obsolete python-django16

* Tue Jan 08 2019 tv <tv> 1.11.18-2.mga7
+ Revision: 1352099
- rebuild with python 3.7

* Sun Jan 06 2019 kekepower <kekepower> 1.11.18-1.mga7
+ Revision: 1350124
- Update to version 1.11.18 to fix CVE-2019-3498 (mga#24128)

* Sun Dec 23 2018 kekepower <kekepower> 1.11.17-1.mga7
+ Revision: 1344634
- Update to version 1.11.17

* Thu Sep 20 2018 umeabot <umeabot> 1.11.15-2.mga7
+ Revision: 1288678
- Mageia 7 Mass Rebuild

* Sat Aug 25 2018 philippem <philippem> 1.11.15-1.mga7
+ Revision: 1254141
- update to 1.11.15 mga#23377 CVE-2018-14574

* Wed May 02 2018 kekepower <kekepower> 1.11.13-1.mga7
+ Revision: 1224549
- Update to version 1.11.13

* Mon Apr 16 2018 kekepower <kekepower> 1.11.12-1.mga7
+ Revision: 1219251
- Fix BR for python-sphinx_rtd_theme
- Update to version 1.11.12
- Use new python[2,3]dist

* Sat Mar 10 2018 kekepower <kekepower> 1.11.11-1.mga7
+ Revision: 1208073
- Update to version 1.11.11

* Sat Mar 10 2018 kekepower <kekepower> 1.8.19-1.mga7
+ Revision: 1208051
- Update to version 1.8.19
- This fixes CVE-2018-7536 and CVE-2018-7537 (mga#22727)

* Sat Aug 05 2017 pterjan <pterjan> 1.8.18-2.mga7
+ Revision: 1135371
- Rebuild for python 3.6

* Wed Apr 05 2017 philippem <philippem> 1.8.18-1.mga6
+ Revision: 1095996
- new upstream fix CVE-2017-7233 and CVE-2017-7234, mga#20628

* Wed Nov 02 2016 philippem <philippem> 1.8.16-1.mga6
+ Revision: 1064734
- update to 1.8.16 fix CVE-2016-9013 and CVE-2016-9014 mga#19690

* Tue Sep 27 2016 philippem <philippem> 1.8.15-1.mga6
+ Revision: 1057084
- update to 1.8.15, fix CVE-2016-7401, mga#19464

* Wed Jul 20 2016 luigiwalser <luigiwalser> 1.8.14-1.mga6
+ Revision: 1042942
- 1.8.14

* Tue May 03 2016 philippem <philippem> 1.8.13-1.mga6
+ Revision: 1009016
- update to 1.8.13

* Mon Apr 04 2016 philippem <philippem> 1.8.12-1.mga6
+ Revision: 998265
- update to 1.8.12

* Tue Mar 08 2016 philippem <philippem> 1.8.11-1.mga6
+ Revision: 987540
- update to 1.8.11

* Thu Mar 03 2016 philippem <philippem> 1.8.10-1.mga6
+ Revision: 984923
- update to 1.8.10, fix CVE-2016-2512 and CVE-2016-2513 mga#17860

* Tue Feb 02 2016 luigiwalser <luigiwalser> 1.8.9-1.mga6
+ Revision: 931904
- 1.8.9

* Thu Nov 26 2015 philippem <philippem> 1.8.7-1.mga6
+ Revision: 906190
- update to 1.8.7, security fix for CVE-2015-8213 mga#17215

* Wed Oct 07 2015 daviddavid <daviddavid> 1.8.4-3.mga6
+ Revision: 887169
- add missing BuildRequires on python-sphinx_rtd_theme
- rebuild for python 3.5
- use new python macros

* Sun Aug 23 2015 philippem <philippem> 1.8.4-2.mga6
+ Revision: 868223
- security issues CVE-2015-5963 and CVE-2015-5964 mga#16607

* Fri Jul 10 2015 philippem <philippem> 1.8.3-2.mga6
+ Revision: 853177
- update to 1.8.3, fix mga#16334 CVE-2015-5143 CVE-2015-5144 CVE-2015-5145

* Fri May 22 2015 luigiwalser <luigiwalser> 1.8.2-1.mga5
+ Revision: 822596
- 1.8.2 (fixes CVE-2015-3982)

* Sat Apr 04 2015 philippem <philippem> 1.8-1.mga5
+ Revision: 819717
- update to 1.8 (LTS)

* Fri Mar 20 2015 luigiwalser <luigiwalser> 1.7.7-2.mga5
+ Revision: 819008
- rebuild for release

* Thu Mar 19 2015 philippem <philippem> 1.7.7-1.mga5
+ Revision: 818959
- update to 1.7.7, fix CVE-2015-2317 CVE-2015-2316 mga#15528

* Thu Jan 15 2015 philippem <philippem> 1.7.3-1.mga5
+ Revision: 810764
- Update to 1.7.3, security fix mga#15045

* Wed Oct 15 2014 umeabot <umeabot> 1.7-4.mga5
+ Revision: 746238
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.7-3.mga5
+ Revision: 727999
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.7-2.mga5
+ Revision: 687966
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 philippem <philippem> 1.7-1.mga5
+ Revision: 671692
- update to 1.7

* Thu Aug 21 2014 philippem <philippem> 1.6.6-1.mga5
+ Revision: 666261
- update to 1.6.6, security fix for CVE-2014-0481, CVE-2014-0482, CVE-2014-0483

* Sat May 31 2014 pterjan <pterjan> 1.6.5-2.mga5
+ Revision: 628550
- Rebuild for new Python

* Thu May 15 2014 oden <oden> 1.6.5-1.mga5
+ Revision: 622907
- 1.6.5 (fixes CVE-2014-1418, CVE-2014-3730)

* Thu Apr 24 2014 philippem <philippem> 1.6.3-2.mga5
+ Revision: 617661
- fix regression with upstream patch dj#22486

* Tue Apr 22 2014 philippem <philippem> 1.6.3-1.mga5
+ Revision: 617465
- 1.6.3 (fixes CVE-2014-0472, CVE-2014-0473, CVE-2014-0474)

* Mon Apr 07 2014 philippem <philippem> 1.6.2-1.mga5
+ Revision: 612783
- update to 1.6.2

* Tue Oct 22 2013 umeabot <umeabot> 1.5.4-3.mga4
+ Revision: 543295
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.5.4-2.mga4
+ Revision: 498360
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 16 2013 oden <oden> 1.5.4-1.mga4
+ Revision: 480299
- 1.5.4 (fixes CVE-2013-1443)

* Wed Sep 11 2013 philippem <philippem> 1.5.3-1.mga4
+ Revision: 477685
- update to 1.5.3, security fix for CVE-2013-4315

* Wed Sep 04 2013 philippem <philippem> 1.5.2-1.mga4
+ Revision: 475168
- split doc in subpackage
+ marja <marja>
- update to 1.5.2 and add python3
- clean spec
- removed PYTHONDONTWRITEBYTECODE= (mga#3348)

* Wed Aug 14 2013 oden <oden> 1.4.6-1.mga4
+ Revision: 466252
- 1.4.6 (security release)

* Tue Feb 26 2013 dmorgan <dmorgan> 1.4.5-1.mga3
+ Revision: 400426
- New version

* Sun Jan 13 2013 umeabot <umeabot> 1.4.3-2.mga3
+ Revision: 378662
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 13 2012 shlomif <shlomif> 1.4.3-1.mga3
+ Revision: 330338
- New version 1.4.3

* Thu Oct 18 2012 philippem <philippem> 1.4.2-1.mga3
+ Revision: 308004
- Fix security issues (https://www.djangoproject.com/weblog/2012/oct/17/security/)

* Sun Aug 12 2012 philippem <philippem> 1.4.1-1.mga3
+ Revision: 280862
- Fix #6986 several security issues.
- CVE-2012-3442: Cross-site scripting in authentication views
- CVE-2012-3443: Denial-of-service in image validation
- CVE-2012-3444: Denial-of-service via get_image_dimensions()

* Wed Jul 18 2012 obgr_seneca <obgr_seneca> 1.4-1.mga3
+ Revision: 272259
- new version 1.4

* Mon Sep 12 2011 misc <misc> 1.3.1-1.mga2
+ Revision: 142749
- upgrade to 1.3.1
- clean the specs file

* Mon Apr 18 2011 misc <misc> 1.3-1.mga1
+ Revision: 87658
- update to latest stable version of django

* Mon Feb 21 2011 ahmad <ahmad> 1.2.3-5.mga1
+ Revision: 55680
- resubmit, now that python-sphinx can be installed
- rebuild to make all pythonegg requires/provides lowercase

* Wed Feb 02 2011 dmorgan <dmorgan> 1.2.3-3.mga1
+ Revision: 46241
- imported package python-django

